#!/bin/bash -

# Purpose: Check the certificate database and send an email alert if a certificate if the expiration date is less than the given argument
# 1 Argument: Number of days
RequestedArgs=1

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

# Going to the PKI directories
cd $PKIDIR

# Starting logging to file
date -R > $LOGDIR/checkCertExpiration.log

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >> $LOGDIR/checkCertExpiration.log 2>&1
        printf "%b" "Usage : $0 Days\n" >> $LOGDIR/checkCertExpiration.log 2>&1
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >> $LOGDIR/checkCertExpiration.log 2>&1
        printf "%b" "usage : $0 Days\n" >> $LOGDIR/checkCertExpiration.log 2>&1
        exit 2
else
        printf "%b" "In progress ...\n" >> $LOGDIR/checkCertExpiration.log 2>&1
fi

# Starting Check

# MAIN DATABASE
echo -e "MAIN DATABASE - Checking Certificate Expiration for MAIN DATABASE ...\n" >> $LOGDIR/checkCertExpiration.log
echo -e "Host\t\t\t\t\t\tStatus\t\tExpires\t\tDays" >> $LOGDIR/checkCertExpiration.log 2>&1
echo -e "-----------------------------------------------\t------------\t------------\t------" >> $LOGDIR/checkCertExpiration.log 2>&1

find $PKIDIR/certs -name "*.crt" -exec sh -c "$BINDIR/ssl-cert-check.sh -b -c {} -x ${1} | grep -i -v \"valid\"" \; >> $LOGDIR/checkCertExpiration.log 2>&1

echo -e "\nDone.\n" >> $LOGDIR/checkCertExpiration.log 2>&1

# Sending Result by eMail
subjectDate=`date +%F`
mailx -s "OpenSSL based PKI  - Certificate Expiration Date Check - ${subjectDate}" "firstname.lastname@mycompany.com" < $LOGDIR/checkCertExpiration.log

# Other method
#
# cd $PKIDIR/certs
# nbCertChecked=0
#
#for certFile in *.crt
#do
#	$BINDIR/openssl x509 -in ${certFile} -enddate -noout 
#	nbCertChecked=`expr $nbCertChecked + 1`  
#done
#
#echo $nbCertChecked


