#!/bin/bash -

# Purpose: Convert a certificate from PEM format to PKCS#12 format
# 2 Arguments: 1st=name of the file without extension, 2nd=Description between single quotes ('')
RequestedArgs=2

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename \"description\"\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename \"description\"\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Converting the certificate
echo -e "\n\nConverting the certificate ..."
openssl pkcs12 -export -in $PKIDIR/certs/${1}.crt -inkey $PKIDIR/private/${1}.key -name "${2}" -out $PKIDIR/certs/${1}.p12

echo -e "\n\nDone. PKCS#12 file available in \"$PKIDIR/certs/${1}.p12\"."
