#!/bin/bash -

# Purpose: Converts a certificate or key from PEM format to DER format
# 2 Arguments: name of the file without extension and type of file (private key or certificate)
RequestedArgs=2

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
	printf "%b" "Error. Not enough arguments.\n" >&2
	printf "%b" "Usage : $0 filename [Key|Cert]\n" >&2
	exit 1
elif (( $# > $RequestedArgs ))
then
	printf "%b" "Error. Too many arguments.\n" >&2
	printf "%b" "usage : $0 filename [Key|Cert]\n" >&2
	exit 2
else
	if ( ("${2}" != "Key") && ("${2}" != "Cert") )
		printf "%b" "usage : $0 filename [Key|Cert]\n" >&2
		exit 2
	else
		printf "%b" "In progress ..."
	fi
fi


# Converting the file
if ("${2}" = "Key")
then
	echo -e "\n\nConverting the Key from PEM to DER ..."
	openssl x509 -in $PKIDIR/private/${1}.key -outform DER -out $PKIDIR/private/${1}.key.der
	echo -e "\n\nDone. Key in DER format is available in file \"$PKIDIR/private/${1}.key.der\"."
elif ("${2}" = "Cert")
	echo -e "\n\nConverting the Certificate from PEM to DER ..."
	openssl x509 -in $PKIDIR/certs/${1}.crt -outform DER -out $PKIDIR/certs/${1}.crt.der
	echo -e "\n\nDone. Certificate is available in file \"$PKIDIR/certs/${1}.crt.der\"."
fi
