#!/bin/bash -

# Purpose: Generates a certificate request for a timestamp certificate
# 1 Argument: name of the file without extension
RequestedArgs=1

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Generating the certificate request

# Generating the key pair
echo -e "\n\nGenerating the RSA private and public key ..." 
openssl genrsa -aes256 -out $PKIDIR/private/${1}.key -rand $PKIDIR/private/.rand 2048

# Protecting the $PKIDIR/private Key
echo -e "\n\nSetting ACL for the private Key ..."
chgrp wheel $PKIDIR/private/${1}.key
chmod 440 $PKIDIR/private/${1}.key
 
# Generating the CSR 
echo -e "\n\nGenerating the certificate request (CSR) using Timestamp configuration file ..."
openssl req -new -config $CONFDIR/req-horo-cert.cnf -key $PKIDIR/private/${1}.key -out $PKIDIR/csr/${1}.csr
 
echo -e "\n\nDone. Request available in file \"$PKIDIR/csr/${1}.csr\"."
echo -e "\nUse \"openssl req -in $PKIDIR/csr/${1}.csr -noout -text\" to review it.\n"
