#!/bin/bash -

# Purpose: Generate the Certificate Revocation List for this PKI
# 0 Argument
RequestedArgs=0

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

# Settinf the name of the Signing Certificate Authority (filename without extension)
SigningAuthority=${UserCertificateAuthority}

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Generating the certificate revocation list

# Generate the CRL
echo -e "\n\nGenerating the User Certificate Revocation List ..."
openssl ca -gencrl -crldays 30 -config $CONFDIR/ca-user-cert.cnf -keyfile $PKIDIR/private/${SigningAuthority}.key -cert $PKIDIR/certs/${SigningAuthority}.crt -out $PKIDIR/crl/crl-user.pem

# Updating Trusted CA Chain
echo -e "\nUpdating Trusted CA Chain ..."
cp $PKIDIR/crl/crl-user.pem $PKIDIR/CAchain/crl-user.pem
c_rehash $PKIDIR/CAchain

echo -e "\n\nDone. Updated User CRL is available in file \"$PKIDIR/crl/crl-user.pem\"."
echo -e "You can view it using \"openssl crl -in $PKIDIR/crl/crl-user.pem -text -noout\".\n"

