#!/bin/bash -

# Purpose: Creates the Root Certificate Authority
# No Argument
RequestedArgs=0

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
	printf "%b" "Error. Not enough arguments.\n" >&2
	printf "%b" "Usage : $0 filename\n" >&2
	exit 1
elif (( $# > $RequestedArgs ))
then
	printf "%b" "Error. Too many arguments.\n" >&2
	printf "%b" "usage : $0 filename\n" >&2
	exit 2
else
	printf "%b" "In progress ..."
fi


# Generating the key pair and the self signed certificate

# Generating the key pair
echo -e "\n\nGenerating the RSA private and public key ..." 
openssl genrsa -aes256 -out $PKIDIR/private/${CertificateAuthority}.key -rand $PKIDIR/private/.rand 4096
 
# Protecting the $PKIDIR/private Key
echo -e "\n\nSetting ACL for the private Key ..."
chgrp wheel $PKIDIR/private/${CertificateAuthority}.key
chmod 440 $PKIDIR/private/${CertificateAuthority}.key

# Self Signing the certificate 
echo -e "\n\nSelf signing the certificate ..."
openssl req -new -x509 -days 7305 -config $CONFDIR/root-ca-cert.cnf -key $PKIDIR/private/${CertificateAuthority}.key -out $PKIDIR/certs/${CertificateAuthority}.crt

# Updating Trusted CA Chain
echo -e "\nUpdating Trusted CA Chain ..."
cp $PKIDIR/certs/${CertificateAuthority}.crt $PKIDIR/CAchain/${CertificateAuthority}.pem
c_rehash $PKIDIR/CAchain

echo -e "\n\nDone. Certificate is available in file \"$PKIDIR/certs/${CertificateAuthority}.crt\", Private Key in file \"$PKIDIR/private/${CertificateAuthority}.key\"."
