#!/bin/bash -

# Purpose: Generate a User Intermediate CA from scratch signed by the Root CA
# 0 Argument
RequestedArgs=0

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=ca

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Generating the certificate from scratch

# Generating the key pair
echo -e "\n\nGenerating the RSA private and public key ..." 
openssl genrsa -aes256 -out $PKIDIR/private/${UserCertificateAuthority}.key -rand $PKIDIR/private/.rand 2048
 
# Protecting the $PKIDIR/private Key
echo -e "\n\nSetting ACL for the private Key ..."
chgrp wheel $PKIDIR/private/${UserCertificateAuthority}.key
chmod 440 $PKIDIR/private/${UserCertificateAuthority}.key
 
# Generating the certificate request
echo -e "\n\nGenerating the Certificate Signing Request ..."
openssl req -new -config $CONFDIR/req-subca-cert.cnf -key $PKIDIR/private/${UserCertificateAuthority}.key -out $PKIDIR/csr/${UserCertificateAuthority}.csr
 
# Generating the certificate
echo -e "\n\nGenerating the User Intermediate CA Certificate signed by the Root CA ..."
openssl ca -config $CONFDIR/ca-subca-cert.cnf -days 5475 -in $PKIDIR/csr/${UserCertificateAuthority}.csr -out $PKIDIR/certs/${UserCertificateAuthority}.crt -notext

# Updating Trusted CA Chain
echo -e "\nUpdating Trusted CA Chain ..."
cp $PKIDIR/certs/${UserCertificateAuthority}.crt $PKIDIR/CAchain/${UserCertificateAuthority}.pem
c_rehash $PKIDIR/CAchain

echo -e "\n\nDone. Certificate is available in file \"$PKIDIR/certs/${UserCertificateAuthority}.crt\", Private Key in file \"$PKIDIR/private/${UserCertificateAuthority}.key\"."
