#!/bin/bash -

# Purpose: Generate a Server certificate with all roles using the provided CSR
# 1 Argument: name of the file without extension
RequestedArgs=1

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=ca

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Generating the certificate using the provided CSR

# Signing the CSR using the root certificate authority
echo -e "\n\nSigning the Server certificate using the root Certificate Authority ..."
openssl ca -config $CONFDIR/ca-server-cert-all_roles.cnf -days 3650 -cert $PKIDIR/certs/${SigningAuthority}.crt -keyfile $PKIDIR/private/${SigningAuthority}.key -in $PKIDIR/csr/${1}.csr -out $PKIDIR/certs/${1}.crt -notext

echo -e "\n\nDone. Certificate is available in file \"$PKIDIR/certs/${1}.crt\"."
