#!/bin/bash -

# Purpose: Renews the Root Certificate Authority
# 0 Argument
RequestedArgs=0

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=ca

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Starting

# Revokes the certificate
echo -e "\n\nCalling revoke-cert-rootca Script ..."
revoke-cert-rootca.sh ${1}

# Sign the certificate request
echo -e "\n\nGenerating the new certificate using the original csr ..."
openssl req -new -x509 -days 7305 -config $CONFDIR/root-ca-cert.cnf -key $PKIDIR/private/${CertificateAuthority}.key -out $PKIDIR/certs/${CertificateAuthority}.crt

# Updating Trusted CA Chain
echo -e "\nUpdating Trusted CA Chain ..."
cp $PKIDIR/certs/${CertificateAuthority}.crt $PKIDIR/CAchain/${CertificateAuthority}.pem
c_rehash $PKIDIR/CAchain

echo -e "\n\nDone. The new certificate is available in \"$PKIDIR/certs/${CertificateAuthority}.crt\".\n"
echo -e "Old certificate has been saved to \"$PKIDIR/revoked/${1}.crt\".\n"

