#!/bin/bash -

# Purpose: Renews the User certificate given in argument
# 1 Argument: The filename of the certificate to be renewed (without extension)
RequestedArgs=1

#undefine alias
\unalias -a

#disable history
hash -r

# Setting environment
BASEDIR=$(dirname $0)
if [ -f $BASEDIR/pki.conf ]; then
	. $BASEDIR/pki.conf

	if [ -z "$APPBASE" ] || [ -z "$PKIDIR" ] || [ -z "$CONFDIR" ] || [ -z "$LOGDIR" ] || [ -z "$BINDIR" ]; then
		printf "%b" "APPBASE, PKIDIR, LOGDIR, BINDIR and CONFDIR variables must be defined in \"$BASEDIR/pki.conf\"\n" >&2
		printf "%b" "PATH $PATH\n" >&2
		exit 1
	fi

else	
	printf "%b" "Error. File \"$BASEDIR/pki.conf\" not found.\n" >&2
        exit 2
fi

SigningAuthority=${UserCertificateAuthority}

# Going to the PKI directories
cd $PKIDIR

# Analysing the arguments
if (( $# < $RequestedArgs ))
then
        printf "%b" "Error. Not enough arguments.\n" >&2
        printf "%b" "Usage : $0 filename\n" >&2
        exit 1
elif (( $# > $RequestedArgs ))
then
        printf "%b" "Error. Too many arguments.\n" >&2
        printf "%b" "usage : $0 filename\n" >&2
        exit 2
else
        printf "%b" "In progress ..."
fi


# Starting

# Revokes the certificate
echo -e "\n\nCalling revoke-user-cert Script ..."
revoke-cert-user.sh ${1}

# Sign the certificate request
echo -e "\n\nGenerating the new user certificate using the original csr ..."
openssl ca -config $CONFDIR/ca-user-cert.cnf -days 3650 -cert $PKIDIR/certs/${SigningAuthority}.crt -keyfile $PKIDIR/private/${SigningAuthority}.key -in $PKIDIR/csr/${1}.csr -out $PKIDIR/certs/${1}.crt -notext

echo -e "\n\nDone. The new certificate is available in \"$PKIDIR/certs/${1}.crt\".\n"
echo -e "Old certificate has been saved to \"$PKIDIR/revoked/${1}.crt\".\n"

